
&GLOBAL-DEFINE USE_STATIC 

class com.amduus.filesystem.FileTools:

  /******************************************************************/
  /* Given a path or file name, return the postfix of the file.     */
  /******************************************************************/
  
  method public {&USE_STATIC} character postfix (input filename as character):
  
    return substring (filename, r-index (filename, ".") + 1).
    
  end.
  
  /******************************************************************/
  /* Given the path or file name, return the basename of the file.  */
  /******************************************************************/
  
  method public {&USE_STATIC} character basename (input filename as character):
  
    return replace (filename, path(filename), "").
  
  end.
  
  /******************************************************************/
  /* Given the path or file name, return the file name without post */
  /* fix.                                                           */
  /******************************************************************/
  
  method public {&USE_STATIC} character prefixname (input filename as character):
  
    return entry (1, basename(filename), ".").
    
  end.
  
  /******************************************************************/
  /* Given the path and file name, return only the path.            */
  /******************************************************************/
  
  method public {&USE_STATIC} character path (input filename as character):
  
    return substring (filename, 1, r-index(filename, dirdelimiter())).
  
  end.
  
  /******************************************************************/
  /* Based on the operating system, determine the directory delim-  */
  /* iter character.                                                */
  /******************************************************************/
  
  method public {&USE_STATIC} character dirdelimiter():
  
    if opsys = "UNIX" then return "/".
    else return "~\".
    
  end.

  /******************************************************************/
  /* Return the file size of the given file.                        */
  /******************************************************************/
  
  method public {&USE_STATIC} integer FileSize(input AbsolutePath as character):
  
    define variable OldFilePath as character no-undo.
    define variable SizeOfFile as integer no-undo.
    
    OldFilePath = file-info:file-name.
    file-info:file-name = AbsolutePath.
    SizeOfFile = file-info:file-size.
    file-info:file-name = OldFilePath.
    
    return SizeOfFile.
    
  end.
  
end.

/**************************************** TEST CODE ************************************

define variable h as class com.amduus.filesystem.FileTools no-undo.
define variable filename as character no-undo.

h = new com.amduus.filesystem.FileTools().

filename = "/tmp/this.txt".
display h:postfix(filename).
display h:path (filename).
display h:basename (filename).
display h:prefixname (filename).
display h:FileSize (filename).

delete object h.

***************************************************************************************/


