
/**************************************************************************/
/*            ,-.                                                         */
/*           / \  `.  __..-,O           #    #    #  ######   ####        */
/*          :   \ --''_..-'.'           #    ##   #  #       #    #       */
/*          |    . .-' `. '.            #    # #  #  #####   #    #       */
/*          :     .     .`.'            #    #  # #  #       #    #       */
/*           \     `.  /  ..            #    #   ##  #       #    #       */
/*            \      `.   ' .           #    #    #  #        ####        */
/*             `,       `.   \                                            */
/*            ,|,`.        `-.\                                           */
/*           '.||  ``-...__..-`                                           */
/*            |  |                      Stuff you want to know....        */
/*            |__|                                                        */
/*            /||\                                                        */
/*           //||\\                                                       */
/*          // || \\                                                      */
/*       __//__||__\\__                                                   */
/*      '--------------' SSt                                              */
/**************************************************************************/
/* This is a mail transport.  It uses the /usr/lib/sendmail command to    */
/* send out mail.                                                         */
/* See Mail.cls for information about generating mail messages.           */
/* out mail.                                                              */
/* This has been tested on Linux.                                         */
/**************************************************************************/


class com.amduus.mail.MailBySendmail inherits com.amduus.mail.Mail:

  define private variable CLI as com.amduus.security.CLI no-undo.
  
  /**************************************************************************/
  /* Constructor                                                            */
  /**************************************************************************/
  
  constructor public MailBySendmail():

    super().  
    
    /* Since it is command line based, we need these tools */
    
    CLI = new com.amduus.security.CLI().

  end. /* constructor */
  
  /**************************************************************************/
  /* Destructor.                                                            */
  /**************************************************************************/
  
  destructor public MailBySendmail():

    delete object CLI.
    
  end. /* desctructor */
  
  /**************************************************************************/
  /* Sends the email using the mail command.  Text only - no mime.          */
  /**************************************************************************/
  
  method public void SendTextEMail():
  
    define variable CmdLine as character no-undo.

    
    /* Since this is a command line tool we are using, we escape the data */
    
    ToEmail = CLI:EscapeCLI(ToEmail).
    CCEmail = CLI:EscapeCLI(CCEmail).
    BCCEmail = CLI:EscapeCLI(BCCEmail).
    
    /* We assemble the message in a temporary file and send it along */
    
    TempMailFile = TempDirectory + Strings:RandomString(10) + ".mail".
   
    GenerateTextMessage(TempMailFile).
    
    /* This comes with the mail invocation for Linux mail. */
    /* Solaris will probably not want the -t               */
    
    CmdLine = "/usr/lib/sendmail -bm "  
            + ToEmail + " " 
            + CCEmail + " " 
            + BCCEmail + " "
            + "< " + TempMailFile
            .
            
    /* Webspeed needs an output destination for os-command */
    
    output to /dev/null.
    os-command value (CmdLine).
    output close.
    
    /* Housekeeping */
    
    if DoDelete then os-delete value(TempMailFile).
    
  end. /* SendMail */
    
  /**************************************************************************/
  /* Uses information in Mail.cls to generate a MIME compliant email.       */
  /**************************************************************************/
  
  method public void SendMimeEMail():
  
    define variable CmdLine as character no-undo.

    
    /* Since this is a command line tool we are using, we escape the data */
    
    ToEmail = CLI:EscapeCLI(ToEmail).
    CCEmail = CLI:EscapeCLI(CCEmail).
    BCCEmail = CLI:EscapeCLI(BCCEmail).
    
    /* We assemble the message in a temporary file and send it along */
    
    TempMailFile = TempDirectory + Strings:RandomString(10) + ".mail".
   
    GenerateMimeMessage(TempMailFile).
    
    CmdLine = "/usr/lib/sendmail -bm "
            + ToEmail + " " 
            + CCEmail + " " 
            + BCCEmail + " "
            + "< " + TempMailFile
            .
            
    /* Webspeed needs an output destination for os-command */
    
    output to /dev/null.
    os-command value (CmdLine).
    output close.
    
    /* Housekeeping */
    
    if DoDelete then os-delete value(TempMailFile).
    
  end. /* SendMimeMail */

end. /* class */

/**************************************************************************

UNIT TEST


TEXT EMAIL TEST

define variable M as com.amduus.mail.MailBySendmail no-undo.

M = new com.amduus.mail.MailBySendmail().

M:ToEmail = "sauge@localhost".
M:FromEmail = "root@localhost".
M:BCCEmail = "root@localhost".
M:Subject = "Test 1".
M:TextBody = "This is a test email".

M:SendTextEMail ().

delete object M.



HTML EMAIL TEST

compile com/amduus/mail/MailBySendmail.cls.

define variable M as com.amduus.mail.MailBySendmail no-undo.

M = new com.amduus.mail.MailBySendmail().

M:ToEmail = "sauge@localhost".
M:FromEmail = "root@localhost".
M:BCCEmail = "root@localhost".
M:Subject = "Test 1".
M:HTMLBody = "<html><body>This is a<b> test</b> email</body></html>".
M:TextBody = "This is a text portion".

M:SendMimeEMail ().

delete object M.


HTML ATTACHMENT TEST

compile com/amduus/mail/MailBySendmail.cls.

define variable M as com.amduus.mail.MailBySendmail no-undo.

M = new com.amduus.mail.MailBySendmail().

M:ToEmail = "sauge@localhost".
M:FromEmail = "root@localhost".
M:BCCEmail = "root@localhost".
M:Subject = "Test 1".
M:HTMLBody = "<html><body>This is a<b> test</b> email</body></html>".
M:TextBody = "This is a text portion".
M:AttachFile ("/tmp/data.xml", "data.xml", ?).

M:SendMimeEMail ().

delete object M.


HTML CID ATTACHMENT TEST
EMBED IMAGE IN HTML AND HAVE AN ATTACHMENT.

compile com/amduus/mail/MailBySendmail.cls.

define variable M as com.amduus.mail.MailBySendmail no-undo.
define variable HTML as character no-undo.

M = new com.amduus.mail.MailBySendmail().

M:ToEmail = "sauge@localhost".
M:FromEmail = "root@localhost".
M:BCCEmail = "root@localhost".
M:Subject = "Test 1".

HTML = "<html><body>"
     + 'This is a <b>test</b> <img src="cid:y1"> email'
     + "</body></html>"
     .

M:HTMLBody = HTML.

M:TextBody = "This is a text portion".
M:AttachFile ("/tmp/data.xml", "data.xml", ?).
M:AttachCID("y1", "/tmp/laptop-clipart.jpg", "").

M:SendMimeEMail ().

delete object M.


**************************************************************************/
